@@ -1,7 +1,7 @@
 package App::gitwrap;
 
-our $DATE = '2016-06-12'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2016-10-09'; # DATE
+our $VERSION = '0.003'; # VERSION
 
 1;
 # ABSTRACT: Git wrapper script
@@ -18,7 +18,7 @@ App::gitwrap - Git wrapper script
 
 =head1 VERSION
 
-This document describes version 0.002 of App::gitwrap (from Perl distribution App-gitwrap), released on 2016-06-12.
+This document describes version 0.003 of App::gitwrap (from Perl distribution App-gitwrap), released on 2016-10-09.
 
 =head1 SYNOPSIS
 
@@ -42,7 +42,7 @@ feature.
 
 =head1 SEE ALSO
 
-C<git> command
+L<git>
 
 L<Git::Wrapper> - similar name but this wraps the C<git> command so it can be
 used like a Perl library.
